@@ -1,4 +1,4 @@
-/* $Id: hawki_bkg.cc,v 1.5 2012/12/07 13:39:40 cgarcia Exp $
+/* $Id: hawki_bkg.cc,v 1.7 2013-09-02 14:36:56 cgarcia Exp $
  *
  * This file is part of the HAWKI Pipeline
  * Copyright (C) 2002,2003 European Southern Observatory
@@ -20,9 +20,9 @@
 
 /*
  * $Author: cgarcia $
- * $Date: 2012/12/07 13:39:40 $
- * $Revision: 1.5 $
- * $Name: hawki-1_8_12 $
+ * $Date: 2013-09-02 14:36:56 $
+ * $Revision: 1.7 $
+ * $Name: not supported by cvs2svn $
  */
 
 #ifdef HAVE_CONFIG_H
@@ -122,7 +122,7 @@ int hawki_bkg_fill_assoc(cpl_frameset * objframes, cpl_propertylist * proplist)
         char                keystr[256];
 
         /* Getting the proplist for this frame */
-        this_frame     = cpl_frameset_get_frame(objframes, iframe);
+        this_frame     = cpl_frameset_get_position(objframes, iframe);
         this_proplist  = cpl_propertylist_load
             (cpl_frame_get_filename(this_frame),0);
         arcfile        = hawki_pfits_get_arcfile(proplist);
@@ -292,7 +292,6 @@ int hawki_bkg_from_running_mean
     int             from_ima;
     int             to_ima;
     int             nima;
-    int             nuse;
     int             nx;
     int             ny;
     
@@ -315,9 +314,6 @@ int hawki_bkg_from_running_mean
     if (from_ima<0) from_ima = 0 ;
     if (to_ima>(nima-1)) to_ima=nima-1 ;
 
-    /* Number of valid planes to consider after edge effects */
-    nuse = to_ima - from_ima ;
-
     /* Get the size of images */
     nx = cpl_image_get_size_x(bkg);
     ny = cpl_image_get_size_y(bkg);
@@ -358,7 +354,8 @@ int hawki_bkg_from_running_mean
                     curima_p = objimages_p[i_ima];
                     curmask_p = maskimages_p[i_ima];
                     if(!curmask_p[pos])
-                        localwin.push_back((double)curima_p[pos]-medians_p[i_ima]);
+                        localwin.push_back
+                            ((double)curima_p[pos]-medians_p[i_ima]);
                 }
             }
             n_win = localwin.size();
@@ -475,7 +472,7 @@ int hawki_bkg_from_running_mean_frame_extension
         	cpl_image * new_image;
         	cpl_frame * frame;
 
-        	frame = cpl_frameset_get_frame(frames_buffer->frames, i_ima);
+        	frame = cpl_frameset_get_position(frames_buffer->frames, i_ima);
         	new_image = hawki_load_frame_extension
         			(frame, iextension + 1, CPL_TYPE_FLOAT);
         	frames_buffer->images[i_ima] = new_image;
@@ -526,7 +523,6 @@ int hawki_bkg_set_obj_mask
  double       mask_off_y)
 {
     cpl_image  * mask_intersection;
-    cpl_image  * mask_trim;
     cpl_mask   * mask_final;
 
     /* The new mask is in float because the distortion correction will
@@ -564,7 +560,6 @@ int hawki_bkg_set_obj_mask
     cpl_image_reject_from_mask(target_image, mask_final);
     
     cpl_image_delete(mask_intersection);
-    cpl_image_delete(mask_trim);
     cpl_mask_delete(mask_final);
 }
 
