@@ -1,5 +1,4 @@
-/* $Id: hawki_load.c,v 1.40 2009/12/04 10:39:14 cgarcia Exp $
- *
+/* 
  * This file is part of the HAWKI Pipeline
  * Copyright (C) 2002,2003 European Southern Observatory
  *
@@ -15,14 +14,7 @@
  *
  * You should have received a copy of the GNU General Public License
  * along with this program; if not, write to the Free Software
- * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
- */
-
-/*
- * $Author: cgarcia $
- * $Date: 2009/12/04 10:39:14 $
- * $Revision: 1.40 $
- * $Name: hawki-1_8_12 $
+ * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301 USA
  */
 
 #ifdef HAVE_CONFIG_H
@@ -86,7 +78,7 @@ cpl_frameset * hawki_extract_frameset(
     /* Loop on the requested frames and store them in out */
     nbext = 0 ;
     for (i=0 ; i<nbframes ; i++) {
-        cur_frame = cpl_frameset_get_frame_const(in, i) ;
+        cur_frame = cpl_frameset_get_position_const(in, i);
         if (!strcmp(cpl_frame_get_tag(cur_frame), tag)) {
             loc_frame = cpl_frame_duplicate(cur_frame) ;
             cpl_frameset_insert(out, loc_frame) ;
@@ -124,7 +116,7 @@ cpl_image * hawki_load_quadrant(
     if (quad < 1 || quad > 4) return NULL ;
 
     /* Load the fnum frame */
-    frame = cpl_frameset_get_frame_const(fset, fnum) ;
+    frame = cpl_frameset_get_position_const(fset, fnum) ;
     fname = cpl_frame_get_filename(frame) ;
 
     /* Load */
@@ -231,7 +223,7 @@ cpl_imagelist * hawki_load_detector(
     for (i=0 ; i<nframes ; i++) {
 
         /* Load the ith frame */
-        frame = cpl_frameset_get_frame_const(fset, i) ;
+        frame = cpl_frameset_get_position_const(fset, i) ;
         fname = cpl_frame_get_filename(frame) ;
 
         /* Get the extension with the wished chip */
@@ -285,7 +277,7 @@ cpl_imagelist * hawki_load_extensions
     for (iframe=0 ; iframe<nframes ; iframe++) {
 
         /* Load the ith frame */
-        frame = cpl_frameset_get_frame_const(fset, iframe) ;
+        frame = cpl_frameset_get_position_const(fset, iframe) ;
         fname = cpl_frame_get_filename(frame) ;
 
         /* Load */
@@ -326,7 +318,7 @@ cpl_image * hawki_load_image(
     if (chip < 1 || chip > HAWKI_NB_DETECTORS) return NULL ;
 
     /* Load the fnum frame */
-    frame = cpl_frameset_get_frame_const(fset, fnum) ;
+    frame = cpl_frameset_get_position_const(fset, fnum) ;
     fname = cpl_frame_get_filename(frame) ;
 
     /* Check that the frame has the right number of extension */
