@@ -1,4 +1,4 @@
-/* $Id: hawki_save.c,v 1.11 2010/11/29 03:37:15 cgarcia Exp $
+/* $Id: hawki_save.c,v 1.12 2013/03/25 11:35:10 cgarcia Exp $
  *
  * This file is part of the HAWKI Pipeline
  * Copyright (C) 2002,2003 European Southern Observatory
@@ -15,14 +15,14 @@
  *
  * You should have received a copy of the GNU General Public License
  * along with this program; if not, write to the Free Software
- * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
+ * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301 USA
  */
 
 /*
  * $Author: cgarcia $
- * $Date: 2010/11/29 03:37:15 $
- * $Revision: 1.11 $
- * $Name: hawki-1_8_12 $
+ * $Date: 2013/03/25 11:35:10 $
+ * $Revision: 1.12 $
+ * $Name:  $
  */
 
 #ifdef HAVE_CONFIG_H
@@ -529,6 +529,7 @@ int hawki_distortion_save
     char                    sval[16] ;
     int                     chip_nb ;
     int                     iext;
+    cpl_errorstate      error_prevstate = cpl_errorstate_get();
 
     /* Test entries */
     if (allframes == NULL) return -1 ;
@@ -637,6 +638,12 @@ int hawki_distortion_save
         }
         cpl_propertylist_delete(qc_ext_list) ;
     }
+        
+    if(!cpl_errorstate_is_equal(error_prevstate ))
+    {
+        cpl_msg_error(__func__, "Cannot save distortion solution") ;
+        return -1 ;
+    }
 
     return 0 ;
 }
@@ -662,7 +669,7 @@ const char * hawki_get_extref_file(const cpl_frameset * frameset)
     {
         const cpl_frame  * frame;
 
-        frame = cpl_frameset_get_frame_const(frameset, iframe);
+        frame = cpl_frameset_get_position_const(frameset, iframe);
         /* Check that it belongs to the raw frames
          * and then check if there are 4 extensions
          */
@@ -681,7 +688,7 @@ const char * hawki_get_extref_file(const cpl_frameset * frameset)
     {
         const cpl_frame  * frame;
 
-        frame = cpl_frameset_get_frame_const(frameset, iframe);
+        frame = cpl_frameset_get_position_const(frameset, iframe);
         /* Check that it belongs to the raw frames
          * and then check if there are 4 extensions
          */
@@ -693,7 +700,7 @@ const char * hawki_get_extref_file(const cpl_frameset * frameset)
         }
     }
     //And if it didn't suceed, use the first frame:
-    fname = cpl_frame_get_filename(cpl_frameset_get_first_const(frameset));
+    fname = cpl_frame_get_filename(cpl_frameset_get_position_const(frameset,0));
 
     return fname;
 }
