@@ -1,4 +1,4 @@
-/* $Id: hawki_utils.c,v 1.54 2012/12/06 16:55:32 cgarcia Exp $
+/* $Id: hawki_utils.c,v 1.57 2013-09-02 14:44:18 cgarcia Exp $
  *
  * This file is part of the HAWKI Pipeline
  * Copyright (C) 2002,2003 European Southern Observatory
@@ -15,14 +15,14 @@
  *
  * You should have received a copy of the GNU General Public License
  * along with this program; if not, write to the Free Software
- * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
+ * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301 USA
  */
 
 /*
  * $Author: cgarcia $
- * $Date: 2012/12/06 16:55:32 $
- * $Revision: 1.54 $
- * $Name: hawki-1_8_12 $
+ * $Date: 2013-09-02 14:44:18 $
+ * $Revision: 1.57 $
+ * $Name: not supported by cvs2svn $
  */
 
 #ifdef HAVE_CONFIG_H
@@ -80,8 +80,8 @@ const char * hawki_get_license(void)
         "\n"
         "You should have received a copy of the GNU General Public License\n"
         "along with this program; if not, write to the Free Software\n"
-        "Foundation, Inc., 59 Temple Place, Suite 330, Boston, \n"
-        "MA  02111-1307  USA" ;
+        "Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, \n"
+        "MA 02110-1301 USA" ;
     return hawki_license ;
 }
 
@@ -715,7 +715,7 @@ cpl_bivector * hawki_get_header_tel_offsets(const cpl_frameset * fset)
     for (i=0 ; i<nfiles ; i++) {
 
         /* X and Y offsets */
-        frame = cpl_frameset_get_frame_const(fset, i) ;
+        frame = cpl_frameset_get_position_const(fset, i) ;
         plist=cpl_propertylist_load(cpl_frame_get_filename(frame),0);
         offsets_x[i] = hawki_pfits_get_cumoffsetx(plist) ;
         offsets_y[i] = hawki_pfits_get_cumoffsety(plist) ;
@@ -753,7 +753,7 @@ double hawki_get_mean_airmass(cpl_frameset *   set)
 
     for (iframe=0 ; iframe<nframes ; iframe++) 
     {
-        cur_frame = cpl_frameset_get_frame(set, iframe);
+        cur_frame = cpl_frameset_get_position(set, iframe);
         plist = cpl_propertylist_load(cpl_frame_get_filename(cur_frame), 0);
         mean_airmass +=   hawki_pfits_get_airmass_start(plist) +
                           hawki_pfits_get_airmass_end(plist); 
@@ -853,7 +853,8 @@ int hawki_detectors_locate_star
     {
         const char * filename;
         filename = cpl_frame_get_filename
-            (cpl_frameset_get_frame_const(in, iframe));
+            (cpl_frameset_get_position_const(in, iframe));
+        labels[iframe] = 0;
         
         for (idet=0 ; idet<HAWKI_NB_DETECTORS ; idet++)
         {
@@ -905,6 +906,38 @@ int hawki_detectors_locate_star
     return 0;
 }
 
+/*----------------------------------------------------------------------------*/
+/**
+  @brief    Check that all the detectors contain have a standard star
+  @param    labels The labels obtained from hawki_detectors_locate_star()
+  @param    nframes The size of labels (which is equal to the number of observed
+                    frames
+  @return   0 if ok. -1 if the check fails 
+
+ */
+/*----------------------------------------------------------------------------*/
+int hawki_check_stdstar_alldetectors(int *labels, int nframes)
+{
+    int     idet, iframe;
+
+    /* Check that the star has been placed in the four detectors */
+    int check_labels[HAWKI_NB_DETECTORS];
+    for(idet=0 ; idet<HAWKI_NB_DETECTORS ; idet++)
+        check_labels[idet] = 0;
+    for(iframe=0 ; iframe<HAWKI_NB_DETECTORS ; iframe++)
+        check_labels[labels[iframe]-1]++;
+    for(idet=0 ; idet<HAWKI_NB_DETECTORS ; idet++)
+    {
+        if(check_labels[idet] != 1)
+        {
+            cpl_msg_error(cpl_func, "No standard star has been placed on "
+                    "detector %d", idet+1);
+            return -1;
+        }
+    }
+    return 0;
+}
+
 /*----------------------------------------------------------------------------*/
 /**
   @brief    Gets the maximum value of a vector according to an array of flags.
@@ -1062,7 +1095,7 @@ int hawki_utils_check_equal_double_keys
         cpl_propertylist * header;
         header = cpl_propertylist_load(
                      cpl_frame_get_filename(
-                     cpl_frameset_get_frame_const(frames, iframe)),0);
+                     cpl_frameset_get_position_const(frames, iframe)),0);
         if(iframe == 0)
             value = (func)(header);
         else
@@ -1099,7 +1132,7 @@ int hawki_utils_check_equal_int_keys
         cpl_propertylist * header;
         header = cpl_propertylist_load(
                      cpl_frame_get_filename(
-                     cpl_frameset_get_frame_const(frames, iframe)),0);
+                     cpl_frameset_get_position_const(frames, iframe)),0);
         if(iframe == 0)
             value = (func)(header);
         else
@@ -1284,7 +1317,7 @@ hawki_frameset_append(cpl_frameset *self, const cpl_frameset *other)
     {
         cpl_frame * newframe;
         newframe = cpl_frame_duplicate
-            (cpl_frameset_get_frame_const(other, iframe));
+            (cpl_frameset_get_position_const(other, iframe));
         if(cpl_frameset_insert(self, newframe) != CPL_ERROR_NONE)
         {
             cpl_error_set(cpl_func, CPL_ERROR_ILLEGAL_INPUT);
