@@ -1,4 +1,4 @@
-/* $Id: hawki_image-test.c,v 1.3 2013/01/15 18:06:16 cgarcia Exp $
+/* $Id: hawki_image-test.c,v 1.5 2013-08-07 13:50:03 cgarcia Exp $
  *
  * This file is part of the HAWKI Pipeline
  * Copyright (C) 2002,2003 European Southern Observatory
@@ -15,14 +15,14 @@
  *
  * You should have received a copy of the GNU General Public License
  * along with this program; if not, write to the Free Software
- * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
+ * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301 USA
  */
 
 /*
  * $Author: cgarcia $
- * $Date: 2013/01/15 18:06:16 $
- * $Revision: 1.3 $
- * $Name: hawki-1_8_12 $
+ * $Date: 2013-08-07 13:50:03 $
+ * $Revision: 1.5 $
+ * $Name: not supported by cvs2svn $
  */
 
 
@@ -84,12 +84,7 @@ static void hawki_image_copy_to_intersection_test(void)
         FILE * dumpfrom;
         FILE * dumptarget;
         
-        FILE * target_read;
-        int    length_target_read;
-        char * content_target_dump;
         FILE * from_read;
-        int    length_from_read;
-        char * content_from_dump;
         
         double val_target;
         double val_from;
@@ -461,4 +456,66 @@ static void hawki_image_copy_to_intersection_test(void)
         cpl_image_delete(from);
         cpl_image_delete(target);
     }
+
+    /* Case 10: null from image */
+    {
+        cpl_image *from = NULL;
+        cpl_image *target = cpl_image_new(1, 1, CPL_TYPE_INT);
+        cpl_size offset_x = 1;
+        cpl_size offset_y = 1;
+        hawki_image_copy_to_intersection(target, from, offset_x, offset_y);
+        cpl_test_error(CPL_ERROR_NULL_INPUT);
+        cpl_image_delete(target);
+    }
+
+    /* Case 11: null target image */
+    {
+        cpl_image *from = cpl_image_new(1, 1, CPL_TYPE_INT);
+        cpl_image *target = NULL;
+        cpl_size offset_x = 1;
+        cpl_size offset_y = 1;
+        hawki_image_copy_to_intersection(target, from, offset_x, offset_y);
+        cpl_test_error(CPL_ERROR_NULL_INPUT);
+        cpl_image_delete(from);
+    }
+
+    /* Case 12: both inputs NULL */
+    {
+        cpl_image *from = NULL;
+        cpl_image *target = NULL;
+        cpl_size offset_x = 1;
+        cpl_size offset_y = 1;
+        hawki_image_copy_to_intersection(target, from, offset_x, offset_y);
+        cpl_test_error(CPL_ERROR_NULL_INPUT);
+    }
+
+    /* Case 13: images not the same type */
+    {
+        cpl_image *from = cpl_image_new(1, 1, CPL_TYPE_INT);
+        cpl_image *target = cpl_image_new(1, 1, CPL_TYPE_DOUBLE);
+        cpl_size offset_x = 1;
+        cpl_size offset_y = 1;
+        hawki_image_copy_to_intersection(target, from, offset_x, offset_y);
+        cpl_test_error(CPL_ERROR_TYPE_MISMATCH);
+        cpl_image_delete(from);
+        cpl_image_delete(target);
+    }
+
+    /* Case 14: images that do not overlap */
+    {
+        cpl_image *from = cpl_image_new(10, 10, CPL_TYPE_DOUBLE);
+        cpl_image *target = cpl_image_new(10, 10, CPL_TYPE_DOUBLE);
+        cpl_image_fill_noise_uniform(from, 1., 10.);
+        cpl_image_fill_noise_uniform(target, 1., 10.);
+        cpl_image *target_orig = cpl_image_duplicate(target);
+        cpl_size offset_x = 11;
+        cpl_size offset_y = 11;
+        hawki_image_copy_to_intersection(target, from, offset_x, offset_y);
+        cpl_test_error(CPL_ERROR_NONE);
+        cpl_test_image_abs(target, target_orig, 0.);
+        cpl_image_delete(from);
+        cpl_image_delete(target);
+        cpl_image_delete(target_orig);
+    }
+
 }
