@@ -1,4 +1,4 @@
-/* $Id: irplib_mkmaster.c,v 1.5 2012/01/12 14:29:41 amodigli Exp $
+/* $Id: irplib_mkmaster.c,v 1.6 2013-02-27 16:00:51 jtaylor Exp $
  *
  * This file is part of the irplib package
  * Copyright (C) 2002,2003 European Southern Observatory
@@ -19,10 +19,10 @@
  */
 
 /*
- * $Author: amodigli $
- * $Date: 2012/01/12 14:29:41 $
- * $Revision: 1.5 $
- * $Name: hawki-1_8_12 $
+ * $Author: jtaylor $
+ * $Date: 2013-02-27 16:00:51 $
+ * $Revision: 1.6 $
+ * $Name: not supported by cvs2svn $
  */
 
 #ifdef HAVE_CONFIG_H
@@ -401,6 +401,8 @@ irplib_mkmaster_dark_qc(const cpl_imagelist* raw_images,
        /* UVES specific stuff: may be this function should not be put in irplib
       irplib_mdark_region_qc(current_dark, parameters, raw_images, recipe_id,qclog);
        */    
+      /* FIXME: still safe if irplib_mdark_region_qc is commented in? */
+      cpl_image_delete(current_dark);
     }
   }
   return cpl_error_get_code();
