@@ -1,4 +1,4 @@
-/* $Id: irplib_slitpos.c,v 1.30 2011/11/23 13:58:45 yjung Exp $
+/* $Id: irplib_slitpos.c,v 1.31 2013-07-04 12:10:12 jtaylor Exp $
  *
  * This file is part of the irplib package
  * Copyright (C) 2002,2003 European Southern Observatory
@@ -19,10 +19,10 @@
  */
 
 /*
- * $Author: yjung $
- * $Date: 2011/11/23 13:58:45 $
- * $Revision: 1.30 $
- * $Name: hawki-1_8_12 $
+ * $Author: jtaylor $
+ * $Date: 2013-07-04 12:10:12 $
+ * $Revision: 1.31 $
+ * $Name: not supported by cvs2svn $
  */
 
 #ifdef HAVE_CONFIG_H
@@ -456,7 +456,7 @@ cpl_error_code irplib_slitpos_find_vert_slit_ends(const cpl_image * self,
 #else
 
     itop = npix - 1;
-    while (itop > ibot && pbinary[itop] != CPL_BINARY_1) itop--;
+    while (itop > ibot && pbinary[itop] == CPL_BINARY_0) itop--;
 
 #endif
 
