@@ -1,4 +1,4 @@
-/* $Id: irplib_polynomial-test.c,v 1.37 2013/01/29 08:43:33 jtaylor Exp $
+/* $Id: irplib_polynomial-test.c,v 1.37 2013-01-29 08:43:33 jtaylor Exp $
  *
  * This file is part of the ESO Common Pipeline Library
  * Copyright (C) 2001-2004 European Southern Observatory
@@ -20,9 +20,9 @@
 
 /*
  * $Author: jtaylor $
- * $Date: 2013/01/29 08:43:33 $
+ * $Date: 2013-01-29 08:43:33 $
  * $Revision: 1.37 $
- * $Name: hawki-1_8_12 $
+ * $Name: not supported by cvs2svn $
  */
 
 /*-----------------------------------------------------------------------------
@@ -202,7 +202,7 @@ static void irplib_polynomial_solve_1d_all_test(void)
                                         DBL_EPSILON, 2.0*DBL_EPSILON);
 
         /* A more extreme case: Same with negative roots */
-        (void)cpl_vector_fill(xtrue, -2.0e-3 * FLT_EPSILON);
+        (void)cpl_vector_fill(xtrue, -0.2 * FLT_EPSILON);
         (void)cpl_vector_set(xtrue, 0, -1.0);
 
         irplib_polynomial_test_root_all(xtrue, nreal, CPL_MATH_PI,
