@@ -1,5 +1,4 @@
-/* $Id: hawki_cal_dark.c,v 1.21 2011/02/16 16:33:21 cgarcia Exp $
- *
+/* 
  * This file is part of the HAWKI Pipeline
  * Copyright (C) 2002,2003 European Southern Observatory
  *
@@ -15,14 +14,7 @@
  *
  * You should have received a copy of the GNU General Public License
  * along with this program; if not, write to the Free Software
- * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
- */
-
-/*
- * $Author: cgarcia $
- * $Date: 2011/02/16 16:33:21 $
- * $Revision: 1.21 $
- * $Name: hawki-1_8_12 $
+ * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301 USA
  */
 
 #ifdef HAVE_CONFIG_H
@@ -50,6 +42,11 @@
                             Functions prototypes
  -----------------------------------------------------------------------------*/
 
+#ifdef __cplusplus
+extern "C"
+#endif
+int cpl_plugin_get_info(cpl_pluginlist * list);
+
 static int hawki_cal_dark_create(cpl_plugin *) ;
 static int hawki_cal_dark_exec(cpl_plugin *) ;
 static int hawki_cal_dark_destroy(cpl_plugin *) ;
@@ -178,6 +175,8 @@ static int hawki_cal_dark_create(cpl_plugin * plugin)
 
     /* Create the parameters list in the cpl_recipe object */
     recipe->parameters = cpl_parameterlist_new() ; 
+    if (recipe->parameters == NULL)
+        return 1;
 
     /* Fill the parameters list */
     /* --sigma */
@@ -346,7 +345,7 @@ static int hawki_cal_dark(
     
     /* Get DIT / NDIT from the header */
     error_prevstate = cpl_errorstate_get();
-    ref_frame = cpl_frameset_get_frame(rawframes, 0) ;
+    ref_frame = cpl_frameset_get_position(rawframes, 0) ;
     if ((plist=cpl_propertylist_load(cpl_frame_get_filename(ref_frame),
                     0)) == NULL) {
         cpl_msg_error(__func__, "Cannot get header from frame");
