@@ -621,7 +621,7 @@ static int hawki_cal_distortion_get_apertures_from_raw_distor
     {
         if ((plist=cpl_propertylist_load
                 (cpl_frame_get_filename
-                 (cpl_frameset_get_first_const(raw_distor)), 0)) == NULL) 
+                 (cpl_frameset_get_position_const(raw_distor, 0)), 0)) == NULL) 
         {
             cpl_msg_error(__func__, "Cannot get header from frame");
             cpl_imagelist_delete(flat_images);
@@ -759,7 +759,7 @@ static cpl_image **  hawki_cal_distortion_get_master_sky
     {
         if ((plist=cpl_propertylist_load
                 (cpl_frame_get_filename
-                 (cpl_frameset_get_first_const(raw_sky_frames)), 0)) == NULL) 
+                 (cpl_frameset_get_position_const(raw_sky_frames, 0)), 0)) == NULL) 
         {
             cpl_msg_error(__func__, "Cannot get header from frame");
             cpl_imagelist_delete(flat_images);
