@@ -1877,7 +1877,7 @@ static int hawki_cal_flat_retrieve_input_param
                &hawki_cal_flat_config.select_min_level[2],
                &hawki_cal_flat_config.select_min_level[3])!=4)
     {
-        if (sscanf(sval, "%f", &hawki_cal_flat_config.select_min_level[0])!=1)
+        if (sscanf(sval, "%lf", &hawki_cal_flat_config.select_min_level[0])!=1)
         {
             return -1;
         }
@@ -1900,7 +1900,7 @@ static int hawki_cal_flat_retrieve_input_param
                &hawki_cal_flat_config.select_max_level[2],
                &hawki_cal_flat_config.select_max_level[3])!=4)
     {
-        if (sscanf(sval, "%f", &hawki_cal_flat_config.select_max_level[0])!=1)
+        if (sscanf(sval, "%lf", &hawki_cal_flat_config.select_max_level[0])!=1)
         {
             return -1;
         }
@@ -1923,7 +1923,7 @@ static int hawki_cal_flat_retrieve_input_param
                hawki_cal_flat_config.select_max_rms+2,
                hawki_cal_flat_config.select_max_rms+3)!=4)
     {
-        if (sscanf(sval, "%f", &hawki_cal_flat_config.select_max_rms[0])!=1)
+        if (sscanf(sval, "%lf", &hawki_cal_flat_config.select_max_rms[0])!=1)
         {
             return -1;
         }
