@@ -1,4 +1,4 @@
-/* $Id: hawki_sci_jitter.c,v 1.34 2013/01/15 09:58:25 cgarcia Exp $
+/* $Id: hawki_sci_jitter.c,v 1.36 2013-09-02 14:32:27 cgarcia Exp $
  *
  * This file is part of the HAWKI Pipeline
  * Copyright (C) 2002,2003 European Southern Observatory
@@ -15,14 +15,14 @@
  *
  * You should have received a copy of the GNU General Public License
  * along with this program; if not, write to the Free Software
- * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
+ * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301 USA
  */
 
 /*
  * $Author: cgarcia $
- * $Date: 2013/01/15 09:58:25 $
- * $Revision: 1.34 $
- * $Name: hawki-1_8_12 $
+ * $Date: 2013-09-02 14:32:27 $
+ * $Revision: 1.36 $
+ * $Name: not supported by cvs2svn $
  */
 
 #ifdef HAVE_CONFIG_H
@@ -510,7 +510,7 @@ static int hawki_sci_jitter(
         int isky;
         for(isky = 0; isky< cpl_frameset_get_size(skyframes); ++isky)
             cpl_frameset_insert(science_frames, 
-                    cpl_frame_duplicate(cpl_frameset_get_frame(skyframes, isky)));
+                    cpl_frame_duplicate(cpl_frameset_get_position(skyframes, isky)));
     }
     
     /* Create the statistics table */
@@ -800,7 +800,7 @@ static cpl_image ** hawki_sci_jitter_reduce
     int                     ioff;
     
     /* Get the header infos */
-    frame = cpl_frameset_get_frame(jitters, 0) ;
+    frame = cpl_frameset_get_position(jitters, 0) ;
     plist=cpl_propertylist_load(cpl_frame_get_filename(frame), 0) ;
     hawki_sci_jitter_output.pixscale = hawki_pfits_get_pixscale(plist) ;
     hawki_sci_jitter_output.dit = hawki_pfits_get_dit(plist) ;
@@ -918,7 +918,7 @@ static cpl_image ** hawki_sci_jitter_reduce
                     int irm = cpl_frameset_get_size(selected_jitter) - 1;
                     cpl_frameset_erase_frame
                         (selected_jitter,
-                         cpl_frameset_get_frame(selected_jitter,irm));
+                         cpl_frameset_get_position(selected_jitter,irm));
                 }
                 cpl_vector_set_size(cpl_bivector_get_x(selected_offsets),
                                     hawki_sci_jitter_config.max_njitter);
@@ -1893,7 +1893,7 @@ static int hawki_sci_jitter_save
     used_frames = cpl_frameset_duplicate(science_frames);
     for(i = 0; i< cpl_frameset_get_size(calib_frames); ++i)
         cpl_frameset_insert(used_frames, 
-                cpl_frame_duplicate(cpl_frameset_get_frame(calib_frames, i)));
+                cpl_frame_duplicate(cpl_frameset_get_position(calib_frames, i)));
 
     /* Create the telescope data statistics */
     telstats = cpl_propertylist_new();
@@ -2133,7 +2133,7 @@ int hawki_sci_jitter_whole_image_algo
 
         /* Computing statistics for this frame */
         cpl_msg_info(cpl_func, "Getting statistics for image %d", iframe + 1);
-        this_target_frame = cpl_frameset_get_frame(obj, iframe);
+        this_target_frame = cpl_frameset_get_position(obj, iframe);
         hawki_image_stats_fill_from_frame
             (raw_jitter_stats, this_target_frame, iframe);
 
