@@ -1,4 +1,4 @@
-/* $Id: hawki_step_apply_dist.c,v 1.10 2011/03/09 10:48:38 cgarcia Exp $
+/* $Id: hawki_step_apply_dist.c,v 1.12 2013-09-02 14:29:09 cgarcia Exp $
  *
  * This file is part of the HAWKI Pipeline
  * Copyright (C) 2002,2003 European Southern Observatory
@@ -15,14 +15,14 @@
  *
  * You should have received a copy of the GNU General Public License
  * along with this program; if not, write to the Free Software
- * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
+ * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301 USA
  */
 
 /*
  * $Author: cgarcia $
- * $Date: 2011/03/09 10:48:38 $
- * $Revision: 1.10 $
- * $Name: hawki-1_8_12 $
+ * $Date: 2013-09-02 14:29:09 $
+ * $Revision: 1.12 $
+ * $Name: not supported by cvs2svn $
  */
 
 #ifdef HAVE_CONFIG_H
@@ -49,6 +49,11 @@
                             Functions prototypes
  -----------------------------------------------------------------------------*/
 
+#ifdef __cplusplus
+extern "C"
+#endif
+int cpl_plugin_get_info(cpl_pluginlist * list);
+
 static int hawki_step_apply_dist_create(cpl_plugin *) ;
 static int hawki_step_apply_dist_exec(cpl_plugin *) ;
 static int hawki_step_apply_dist_destroy(cpl_plugin *) ;
@@ -300,8 +305,8 @@ int hawki_step_apply_dist_compute_and_save
 
     /* Get the distortion filename and distortion maps */
     cpl_msg_info(__func__,"Creating the distortion maps");
-    distframe_x = cpl_frameset_get_first_const(distortion_x);
-    distframe_y = cpl_frameset_get_first_const(distortion_y);
+    distframe_x = cpl_frameset_get_position_const(distortion_x, 0);
+    distframe_y = cpl_frameset_get_position_const(distortion_y, 0);
     first_image = hawki_load_image(objects, 0, 1, CPL_TYPE_FLOAT);
     nx = cpl_image_get_size_x(first_image);
     ny = cpl_image_get_size_y(first_image);
@@ -360,7 +365,7 @@ int hawki_step_apply_dist_compute_and_save
         cpl_msg_info(__func__,"Correcting distortion in frame %d",iframe+1);
         
         /* Load the HAWKI images */
-        this_frame = cpl_frameset_get_frame(objects, iframe);
+        this_frame = cpl_frameset_get_position(objects, iframe);
         if((object_images = hawki_load_frame(this_frame, CPL_TYPE_FLOAT)) == NULL)
         {
             cpl_msg_error(__func__,"Could not load input object images");
@@ -396,10 +401,10 @@ int hawki_step_apply_dist_compute_and_save
         cpl_frameset_insert(used_frameset, cpl_frame_duplicate(this_frame));
         cpl_frameset_insert
             (used_frameset,cpl_frame_duplicate
-                 (cpl_frameset_get_first_const((distortion_x))));
+                 (cpl_frameset_get_position_const(distortion_x, 0)));
         cpl_frameset_insert
             (used_frameset,cpl_frame_duplicate
-                 (cpl_frameset_get_first_const((distortion_y))));
+                 (cpl_frameset_get_position_const(distortion_y, 0)));
             
         /* Save the corrected image */
         if (hawki_step_apply_dist_save
@@ -486,7 +491,7 @@ static int hawki_step_apply_dist_save
     }
     
     /* Write the image */
-    snprintf(filename, 256, "hawki_step_apply_dist_%03d.fits", iserie+1);
+    snprintf(filename, 256, "hawki_step_apply_dist_%04d.fits", iserie+1);
     if(hawki_imagelist_save
         (recipe_frameset,
          recipe_parlist,
