@@ -372,7 +372,7 @@ static int hawki_step_basic_calib_applycal_qc_save
     {
         if ((plist=cpl_propertylist_load
                 (cpl_frame_get_filename
-                 (cpl_frameset_get_first_const(raw_target)), 0)) == NULL) 
+                 (cpl_frameset_get_position_const(raw_target, 0)), 0)) == NULL) 
         {
             cpl_msg_error(__func__, "Cannot get header from frame");
             cpl_imagelist_delete(flat_images);
@@ -399,7 +399,7 @@ static int hawki_step_basic_calib_applycal_qc_save
         /* Loading the target */
         cpl_msg_indent_more();
         cpl_msg_info(__func__, "Loading frame %d", iframe+1) ;
-        target_frame = cpl_frameset_get_frame(raw_target, iframe);
+        target_frame = cpl_frameset_get_position(raw_target, iframe);
         if(target_frame != NULL)
             target_images = hawki_load_frame(target_frame, CPL_TYPE_FLOAT);
         if(target_images == NULL)
