@@ -364,7 +364,7 @@ static int hawki_step_combine(
         int iframe;
         for(iframe=0; iframe < cpl_frameset_get_size(bpmbkg); iframe++)
             cpl_frameset_insert(used_frames, cpl_frame_duplicate(
-                    cpl_frameset_get_frame(bpmbkg,iframe)));
+                    cpl_frameset_get_position(bpmbkg, iframe)));
         if(cpl_frameset_get_size(bpmbkg) != cpl_frameset_get_size(objframes))
         {
             cpl_msg_error(__func__,"Incompatible number of science and bad bkg"
