@@ -1,4 +1,4 @@
-/* $Id: hawki_step_detect_obj.c,v 1.28 2013-03-25 11:36:35 cgarcia Exp $
+/* $Id: hawki_step_detect_obj.c,v 1.28 2013/03/25 11:36:35 cgarcia Exp $
  *
  * This file is part of the HAWKI Pipeline
  * Copyright (C) 2002,2003 European Southern Observatory
@@ -20,9 +20,9 @@
 
 /*
  * $Author: cgarcia $
- * $Date: 2013-03-25 11:36:35 $
+ * $Date: 2013/03/25 11:36:35 $
  * $Revision: 1.28 $
- * $Name: not supported by cvs2svn $
+ * $Name:  $
  */
 
 #ifdef HAVE_CONFIG_H
@@ -91,8 +91,9 @@ static int hawki_step_detect_obj_save
 static struct 
 {
     /* Inputs */
-    double sigma_det;
+    double detect_sigma;
     int    growing_radius;
+    int    median_smooth;
 } hawki_step_detect_obj_config;
 
 static struct 
@@ -187,11 +188,20 @@ static int hawki_step_detect_obj_create(cpl_plugin * plugin)
         return 1;
 
     /* Fill the parameters list */
-    /* --sigma_det */
-    p = cpl_parameter_new_value("hawki.hawki_step_detect_obj.sigma_det", 
+    /* --median_smooth */
+    p = cpl_parameter_new_value("hawki.hawki_step_detect_obj.median_smooth", 
+                                CPL_TYPE_INT, "box size for a median smoothing"
+                                " of the image before the detection",
+                                "hawki.hawki_step_detect_obj", 3);
+    cpl_parameter_set_alias(p, CPL_PARAMETER_MODE_CLI, "median_smooth");
+    cpl_parameter_disable(p, CPL_PARAMETER_MODE_ENV);
+    cpl_parameterlist_append(recipe->parameters, p);
+
+    /* --detect_sigma */
+    p = cpl_parameter_new_value("hawki.hawki_step_detect_obj.detect_sigma", 
                                 CPL_TYPE_DOUBLE, "detection level",
-                                "hawki.hawki_step_detect_obj", 6.);
-    cpl_parameter_set_alias(p, CPL_PARAMETER_MODE_CLI, "sigma_det");
+                                "hawki.hawki_step_detect_obj", 7.);
+    cpl_parameter_set_alias(p, CPL_PARAMETER_MODE_CLI, "detect_sigma");
     cpl_parameter_disable(p, CPL_PARAMETER_MODE_ENV);
     cpl_parameterlist_append(recipe->parameters, p);
 
@@ -394,17 +404,20 @@ int hawki_step_detect_obj_retrieve_input_param
 
     par = NULL ;
     par = cpl_parameterlist_find
-        (parlist, "hawki.hawki_step_detect_obj.sigma_det");
-    hawki_step_detect_obj_config.sigma_det = cpl_parameter_get_double(par);
+        (parlist, "hawki.hawki_step_detect_obj.detect_sigma");
+    hawki_step_detect_obj_config.detect_sigma = cpl_parameter_get_double(par);
     par = cpl_parameterlist_find
         (parlist, "hawki.hawki_step_detect_obj.growing_radius");
     hawki_step_detect_obj_config.growing_radius = cpl_parameter_get_int(par);
+    par = cpl_parameterlist_find
+        (parlist, "hawki.hawki_step_detect_obj.median_smooth");
+    hawki_step_detect_obj_config.median_smooth = cpl_parameter_get_int(par);
     if(hawki_step_detect_obj_config.growing_radius > 100)
     {
         cpl_msg_error(__func__,"The maximum radius allowed is 100");
         return -1;
     }
-    if(hawki_step_detect_obj_config.sigma_det <= 0 )
+    if(hawki_step_detect_obj_config.detect_sigma <= 0 )
     {
         cpl_msg_error(__func__,"Detection sigma has to be greater than 0");
         return -1;
@@ -442,6 +455,7 @@ static cpl_apertures  ** hawki_step_detect_obj_mask_and_apertures
     for (idet=0 ; idet<HAWKI_NB_DETECTORS ; idet++)
     {
         cpl_image  * chip_image;
+        cpl_image  * filt_ima;
         cpl_image  * chip_image_sort;
         cpl_mask   * object_mask;
         cpl_mask   * kernel_op;
@@ -469,12 +483,28 @@ static cpl_apertures  ** hawki_step_detect_obj_mask_and_apertures
             return NULL ;
         }
         
-        /* Subtract the median of the frame first */
+        /* Median smoothing of the image*/
+        if(hawki_step_detect_obj_config.median_smooth > 0)
+        {
+            int median_smooth = hawki_step_detect_obj_config.median_smooth;
+            kernel_op = cpl_mask_new(median_smooth, median_smooth);
+            cpl_mask_not(kernel_op);
+            filt_ima = cpl_image_new(cpl_image_get_size_x(chip_image),
+                    cpl_image_get_size_y(chip_image),
+                    cpl_image_get_type(chip_image));
+            cpl_image_filter_mask(filt_ima, chip_image, kernel_op, CPL_FILTER_MEDIAN, 
+                                  CPL_BORDER_FILTER);
+            cpl_mask_delete(kernel_op);
+            cpl_image_delete(chip_image);
+            chip_image = filt_ima;
+        }
+
+        /* Compute the median of the frame first */
         chip_image_sort = cpl_image_duplicate(chip_image);
         bkg_level = cpl_image_get_median(chip_image);
-        bkg_noise = hawki_image_float_get_sigma_from_quartile(chip_image_sort); 
+        bkg_noise = hawki_image_float_get_sigma_from_quartile(chip_image_sort);
         cpl_image_delete(chip_image_sort);
-        threshold = bkg_level + hawki_step_detect_obj_config.sigma_det * bkg_noise;        
+        threshold = bkg_level + hawki_step_detect_obj_config.detect_sigma * bkg_noise;        
         cpl_msg_info(__func__, "Background:       %f",bkg_level);
         cpl_msg_info(__func__, "Background noise: %f",bkg_noise);
         
@@ -961,7 +991,7 @@ static void hawki_step_detect_obj_get_pscale
     cpl_errorstate      error_prevstate = cpl_errorstate_get();
     
     /* Get the header infos */
-    firstframe = cpl_frameset_get_frame(combframes, 0) ;
+    firstframe = cpl_frameset_get_position(combframes, 0) ;
     plist=cpl_propertylist_load(cpl_frame_get_filename(firstframe), 0) ;
     hawki_step_detect_obj_output.pixscale = hawki_pfits_get_pixscale(plist);
     cpl_propertylist_delete(plist) ;
