@@ -1,4 +1,4 @@
-/* $Id: hawki_step_refine_offsets.c,v 1.17 2011/10/24 10:42:12 cgarcia Exp $
+/* $Id: hawki_step_refine_offsets.c,v 1.19 2013-09-02 14:35:52 cgarcia Exp $
  *
  * This file is part of the HAWKI Pipeline
  * Copyright (C) 2002,2003 European Southern Observatory
@@ -15,14 +15,14 @@
  *
  * You should have received a copy of the GNU General Public License
  * along with this program; if not, write to the Free Software
- * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
+ * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301 USA
  */
 
 /*
  * $Author: cgarcia $
- * $Date: 2011/10/24 10:42:12 $
- * $Revision: 1.17 $
- * $Name: hawki-1_8_12 $
+ * $Date: 2013-09-02 14:35:52 $
+ * $Revision: 1.19 $
+ * $Name: not supported by cvs2svn $
  */
 
 #ifdef HAVE_CONFIG_H
@@ -63,6 +63,11 @@
                             Functions prototypes
  -----------------------------------------------------------------------------*/
 
+#ifdef __cplusplus
+extern "C"
+#endif
+int cpl_plugin_get_info(cpl_pluginlist * list);
+
 static int hawki_step_refine_offsets_create(cpl_plugin *) ;
 static int hawki_step_refine_offsets_exec(cpl_plugin *) ;
 static int hawki_step_refine_offsets_destroy(cpl_plugin *) ;
@@ -451,7 +456,7 @@ static int hawki_step_refine_offsets_fine
     /* Get the size of the detectors of the first extension */
     header = cpl_propertylist_load
         (cpl_frame_get_filename
-                (cpl_frameset_get_first_const(science_obj_frames)), 1);
+                (cpl_frameset_get_position_const(science_obj_frames, 0)), 1);
     nx = hawki_pfits_get_naxis1(header);
     ny = hawki_pfits_get_naxis2(header);
     cpl_propertylist_delete(header);
@@ -693,7 +698,7 @@ static cpl_bivector ** hawki_step_refine_offsets_read_select_objects
     
     /* Get the objects */
     cpl_msg_info(__func__,"Getting the reference object positions");
-    reference_obj_frame = cpl_frameset_get_first_const(reference_obj_frames);
+    reference_obj_frame = cpl_frameset_get_position_const(reference_obj_frames, 0);
     obj_param = hawki_load_tables(reference_obj_frame);
     if(obj_param == NULL)
     {
