@@ -1,4 +1,4 @@
-/* $Id: hawki_step_subtract_bkg.c,v 1.18 2012/11/30 14:50:51 cgarcia Exp $
+/* $Id: hawki_step_subtract_bkg.c,v 1.20 2013-09-02 14:24:14 cgarcia Exp $
  *
  * This file is part of the HAWKI Pipeline
  * Copyright (C) 2008 European Southern Observatory
@@ -15,14 +15,14 @@
  *
  * You should have received a copy of the GNU General Public License
  * along with this program; if not, write to the Free Software
- * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
+ * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301 USA
  */
 
 /*
  * $Author: cgarcia $
- * $Date: 2012/11/30 14:50:51 $
- * $Revision: 1.18 $
- * $Name: hawki-1_8_12 $
+ * $Date: 2013-09-02 14:24:14 $
+ * $Revision: 1.20 $
+ * $Name: not supported by cvs2svn $
  */
 
 #ifdef HAVE_CONFIG_H
@@ -324,7 +324,7 @@ static int hawki_step_subtract_bkg_apply_one_to_one_save
         /* Read the object frame */
         cpl_msg_indent_more();
         cpl_msg_info(__func__, "Applying correction to object %d", iobj+1) ;
-        obj_frame = cpl_frameset_get_frame(objframes, iobj);
+        obj_frame = cpl_frameset_get_position(objframes, iobj);
         cpl_frameset_insert(used_frameset, cpl_frame_duplicate(obj_frame));
         if(obj_frame != NULL)
             obj_images = hawki_load_frame(obj_frame, CPL_TYPE_FLOAT);
@@ -337,7 +337,7 @@ static int hawki_step_subtract_bkg_apply_one_to_one_save
         }
 
         /* Read the bkg */
-        bkg_frame = cpl_frameset_get_frame(bkgframes, iobj);
+        bkg_frame = cpl_frameset_get_position(bkgframes, iobj);
         cpl_frameset_insert(used_frameset, cpl_frame_duplicate(bkg_frame));
         if(bkg_frame != NULL)
             bkg_images = hawki_load_frame(bkg_frame, CPL_TYPE_FLOAT);
@@ -396,7 +396,7 @@ static int hawki_step_subtract_bkg_apply_one_to_all_save
 
     /* Read the bkg */
     cpl_msg_info(__func__,"Using the same bkg for all the objects");
-    bkg_frame = cpl_frameset_get_first(bkgframes);
+    bkg_frame = cpl_frameset_get_position(bkgframes, 0);
     if(bkg_frame != NULL)
         bkg_images = hawki_load_frame(bkg_frame, CPL_TYPE_FLOAT);
     if(bkg_images == NULL)
@@ -419,7 +419,7 @@ static int hawki_step_subtract_bkg_apply_one_to_all_save
         /* Read the object frame */
         cpl_msg_indent_more();
         cpl_msg_info(__func__, "Applying correction to object %d", iobj+1) ;
-        obj_frame = cpl_frameset_get_frame(objframes, iobj);
+        obj_frame = cpl_frameset_get_position(objframes, iobj);
         if(obj_frame != NULL)
             obj_images = hawki_load_frame(obj_frame, CPL_TYPE_FLOAT);
         cpl_frameset_insert(used_frameset, cpl_frame_duplicate(obj_frame));
